import { default as React } from 'react';

/**
 * A type that can be returned by a promise or as is.
 */
export type Promisable<T> = T | Promise<T>;
/**
 * Asynchronous data state.
 */
interface AsyncState<T> {
    /**
     * Determine if we are waiting for the promise result or not.
     */
    pending: boolean;
    /**
     * The promise which is retrieved (or has retrieved) data.
     */
    promise: Promisable<T>;
    /**
     * Error thrown by the promise.
     */
    error: Error;
    /**
     * The promise result.
     */
    data: T;
}
/**
 * A promise production function.
 */
export type PromiseFn<T> = () => Promise<T>;
/**
 * React hook for promise result retrieval.
 * @param promise The promise or a function which produces a promise.
 * @param deps When one of the `deps` change, it will wait for the promise again.
 */
export declare function useAsync<T>(promise: Promisable<T> | PromiseFn<T>, deps?: any[]): [AsyncState<T>, React.Dispatch<T>];
/**
 * Wait for the promise to be fulfilled to render the children.
 * @param async The async state.
 * @param children Renderer function of the children, takes promised data as argument.
 * @param fallback Content shown when the promise is not fulfilled yet.
 * @constructor
 */
export declare function Await<T>({ async, children, fallback }: {
    async: AsyncState<T>;
    children: (async: T) => React.ReactElement;
    fallback?: React.ReactElement;
}): React.JSX.Element;
/**
 * Easy async component with fallback and fulfilled children render.
 * @param promise The promise.
 * @param children Renderer function of the children, takes promised data as argument.
 * @param fallback Content shown when the promise is not fulfilled yet.
 * @constructor
 */
export declare function Async<T>({ promise, fallback, children }: {
    promise: Promisable<T> | PromiseFn<T>;
    children: (async: T) => React.ReactElement;
    fallback?: React.ReactElement;
}): React.JSX.Element;
export {};
