import { default as React } from 'react';
import { Modify } from '../../Utils';

/**
 * Generic select component properties.
 */
export type SelectProperties<OptionKey extends keyof any, Option> = React.PropsWithChildren<Modify<React.InputHTMLAttributes<HTMLInputElement>, {
    /**
     * The currently selected option(s).
     */
    value: OptionKey | OptionKey[];
    /**
     * Called when new options are selected.
     * @param newValue
     */
    onChange: (newValue: OptionKey | OptionKey[]) => void;
    /**
     * Options list or a way to get it from a given search.
     */
    options: Record<OptionKey, Option>;
    /**
     * Render an option.
     * @param option The option to render.
     */
    renderOption?: (option: Option) => React.ReactNode;
    /**
     * Option match function. Return true if the given option matches the given search query.
     * @param search The search query.
     * @param option The option that should match the search query.
     */
    match?: (search: string, option: Option) => boolean;
    /**
     * Min count of options to allow to select.
     * 0 by default, 1 when required is true.
     */
    selectibleMinCount?: number;
    /**
     * Max count of options to allow to select.
     * 1 by default when multiple is false, infinity when multiple is true.
     */
    selectibleMaxCount?: number;
    /**
     * True to allow to select an infinite count of options.
     * false by default.
     */
    multiple?: boolean;
    /**
     * When true, the select loses focus when a new option is selected (by clicking or pressing Enter).
     * false by default.
     */
    blurOnSelect?: boolean;
    /**
     * When true, the select loses focus when the max count of selectible options have been reached (by clicking or pressing Enter).
     * true by default.
     */
    blurWhenMaxCountSelected?: boolean;
    type?: never;
    role?: never;
}>>;
/**
 * Generic select component.
 */
export declare function Select<OptionKey extends keyof any, Option>({ className, value, onChange, options, renderOption, match, required, selectibleMinCount, selectibleMaxCount, multiple, blurOnSelect, blurWhenMaxCountSelected, onKeyDown, type, role, children, ...props }: SelectProperties<OptionKey, Option>): React.ReactElement;
