import { default as React } from 'react';
import { GlobalState, GlobalStateReducers } from '../../GlobalState';

/**
 * Type of step key.
 */
export type StepKeyType = string;
/**
 * Steps global state data type.
 */
export interface StepsGlobalStateType {
    /**
     * Steps list, by their order of apparition.
     */
    steps: {
        key: StepKeyType;
        title?: React.ReactNode;
    }[];
    /**
     * The index of the current step in the steps list.
     */
    currentStepIndex: number;
}
/**
 * The steps global state modification functions.
 */
declare class StepsGlobalStateReducers extends GlobalStateReducers<StepsGlobalStateType> {
    /**
     * Register a new step with its step key.
     * @param newStepKey The step key to register.
     */
    registerStep(newStepKey: StepKeyType, newStepTitle?: React.ReactNode): void;
    /**
     * Remove an old step with its step key.
     * @param oldStepKey The step key to remove.
     */
    removeStep(oldStepKey: StepKeyType): void;
    /**
     * Set the current step from its key.
     * @param stepKey The step key to set as the current one.
     */
    setCurrentStep(stepKey: StepKeyType): void;
    /**
     * Get the next step key.
     */
    getNextStep(): StepKeyType;
    /**
     * Get the previous step key.
     */
    getPreviousStep(): StepKeyType;
}
/**
 * The steps global state.
 */
export declare const stepsGlobalState: GlobalState<StepsGlobalStateType, StepsGlobalStateReducers>;
/**
 * Hook of the current step key in a steps component.
 */
export declare function useCurrentStepKey(): StepKeyType;
/**
 * Steps navigator
 */
export interface StepsNavigator {
    /**
     * Go to the next step.
     */
    next(): void;
    /**
     * Return to the previous step.
     */
    previous(): void;
    /**
     * Go to the given step.
     * @param stepKey The step key to join.
     */
    set(stepKey: StepKeyType): void;
}
/**
 * Hook of the steps' navigator.
 */
export declare function useStepsNavigator(): StepsNavigator;
export {};
